==> microprofile-config-tck-2.0-sources.jar: org/eclipse/microprofile/config/tck/SimpleValuesBean.java <==
/*
 * Copyright (c) 2016-2017 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.eclipse.microprofile.config.tck;

import javax.enterprise.context.Dependent;
import javax.inject.Inject;

import org.eclipse.microprofile.config.inject.ConfigProperty;

@Dependent
public class SimpleValuesBean {

    @Inject
    @ConfigProperty(name = "my.string/property")
    private String stringProperty;

    @Inject
    @ConfigProperty(name = "my.boolean.property")
    private boolean booleanProperty;

    @Inject
    @ConfigProperty(name = "my.int/property")
    private int intProperty;

    public String getStringProperty() {
        return this.stringProperty;
    }

    public boolean getBooleanProperty() {
        return this.booleanProperty;
    }

    public int getIntProperty() {
        return this.intProperty;
    }
}

==> microprofile-config-tck-3.0-sources.jar: org/eclipse/microprofile/config/tck/SimpleValuesBean.java <==
/*
 * Copyright (c) 2016-2017 Contributors to the Eclipse Foundation
 *
 * See the NOTICE file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.eclipse.microprofile.config.tck;

import org.eclipse.microprofile.config.inject.ConfigProperty;

import jakarta.enterprise.context.Dependent;
import jakarta.inject.Inject;

@Dependent
public class SimpleValuesBean {

    @Inject
    @ConfigProperty(name = "my.string/property")
    private String stringProperty;

    @Inject
    @ConfigProperty(name = "my.boolean.property")
    private boolean booleanProperty;

    @Inject
    @ConfigProperty(name = "my.int/property")
    private int intProperty;

    public String getStringProperty() {
        return this.stringProperty;
    }

    public boolean getBooleanProperty() {
        return this.booleanProperty;
    }

    public int getIntProperty() {
        return this.intProperty;
    }
}
